AccountArg

Struct AccountArg 

pub struct AccountArg {
    pub name: String,
}
Available on crate feature terminal only.
The account name flag parser.

Fields

name: String

Override the default account.

An account name corresponds to an entry in the table at the root level of your TOML configuration file.