pub struct CompletionCommand {
pub shells: Vec<Shell>,
pub dir: PathBuf,
}Available on crate feature
terminal only.Expand description
Generate completion script for the give shell(s) to the given directory.
This command allows you to generate completion script for a given shell. The script is printed to the standard output. If you want to write it to a file, just use unix redirection.
Fields
shells: Vec<Shell>Shell for which completion script should be generated for.
dir: PathBufSave completion script to the given directory.
Implementations