ManualCommand

Struct ManualCommand 

pub struct ManualCommand {
    pub dir: PathBuf,
}
Available on crate feature terminal only.
Generate manual pages to the given directory.

This command allows you to generate manual pages (following the man page format) to the given directory. If the directory does not exist, it will be created. Any existing man pages will be overriden.

Fields

dir: PathBuf

Directory where man files should be generated in.

Implementations

Source

impl ManualCommand

pub fn execute(self, printer: &mut impl Printer, command: Command) -> Result<()>

Generates the man pages and reports how many landed where.