Available on crate feature
terminal only.Expand description
Command failure reporting to stdout.
Structs
- Error
Report - Wraps an
anyhow::Errorto render it, with its source chain and backtrace, as text or JSON.
terminal only.Command failure reporting to stdout.
anyhow::Error to render it, with its source chain and
backtrace, as text or JSON.