PrintTable

Trait PrintTable 

pub trait PrintTable {
    // Required method
    fn print(
        &self,
        writer: &mut dyn Write,
        table_max_width: Option<u16>,
    ) -> Result<()>;
}
Available on crate feature terminal only.
A value that can render itself as a table.

Required Methods

fn print( &self, writer: &mut dyn Write, table_max_width: Option<u16>, ) -> Result<()>

Writes the table to the given writer, capped at an optional maximum width.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors