Module table

Module table 

Available on crate feature table only.
Re-export of the comfy-table tabular output crate.

Consumers of pimalaya-cli enable the table feature and reach the underlying types via crate::table instead of pulling comfy-table in directly.

Modules

modifiers
Contains modifiers, that can be used to alter certain parts of a preset.
For instance, the UTF8_ROUND_CORNERS replaces all corners with round UTF8 box corners.
presets
This module provides styling presets for tables.
Every preset has an example preview.

Structs

Cell
A stylable table cell with content.
Cells
A simple wrapper type for a Vec<Cell>.
Column
A representation of a table’s column. Useful for styling and specifying constraints how big a column should be.
ColumnCellIter
An iterator over cells of a specific column. A dedicated struct is necessary, as data is usually handled by rows and thereby stored in Table::rows. This type is returned by Table::column_cells_iter.
Row
Each row contains Cells and can be added to a Table.
Table
This is the main interface for building a table. Each table consists of Rows, which in turn contain Cells.

Enums

Attribute
Represents an attribute.
CellAlignment
This can be set on columns and cells.
Color
Represents a color.
ColumnConstraint
A Constraint can be added to a columns.
ContentArrangement
Specify how comfy_table should arrange the content in your table.
TableComponent
All configurable table components. A character can be assigned to each component via Table::set_style. This is then used to draw character of the respective component to the commandline.
Width