pub struct AccountArg {
pub name: String,
}Available on crate feature
terminal only.Expand description
The account name flag parser.
Fields
name: StringOverride the default account.
An account name corresponds to an entry in the table at the root level of your TOML configuration file.